@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -39,7 +39,7 @@ class KSIEVEUI_EXPORT ManageSieveScriptsDialog : public QDialog
 
 public:
     explicit ManageSieveScriptsDialog(SieveImapPasswordProvider *passwordProvider, QWidget *parent = nullptr);
-    ~ManageSieveScriptsDialog();
+    ~ManageSieveScriptsDialog() override;
 
 Q_SIGNALS:
     void finished();
